@@ -3,10 +3,11 @@ use warnings;
 
 package WebService::Nestoria::Search;
 {
-  $WebService::Nestoria::Search::VERSION = '1.021000';
+  $WebService::Nestoria::Search::VERSION = '1.021001';
 }
 
 use Carp;
+use URI;
 use WebService::Nestoria::Search::Request;
 use WebService::Nestoria::Search::MetadataResponse;
 
@@ -16,7 +17,7 @@ WebService::Nestoria::Search - Perl interface to the Nestoria Search public API.
 
 =head1 VERSION
 
-version 1.021000
+version 1.021001
 
 =head1 SYNOPSIS
 
@@ -171,7 +172,7 @@ my %Config = (
 );
 
 ## filled in Search/Request.pm
-our $RecentRequsetUrl;
+our $RecentRequestUrl;
 
 my %GlobalDefaults = (
     'warnings'                => '1',
@@ -608,6 +609,27 @@ sub metadata {
     return WebService::Nestoria::Search::MetadataResponse->new($response->get_hashref);
 }
 
+=head2 last_request_uri
+
+Returns a URI object representing the URL that was last fetched by
+WebService::Nestoria::Search::Request.
+
+=cut
+
+sub last_request_uri {
+    return URI->new($RecentRequestUrl);
+}
+
+=head2 last_request_url
+
+Returns the URL that was last fetched by WebService::Nestoria::Search::Request.
+
+=cut
+
+sub last_request_url {
+    return $RecentRequestUrl;
+}
+
 =head1 Warnings
 
 Warnings is true by default, and means that errors are output to STDERR as well as being returned via $@. This can be turned off either on the C<use> line
